@@ -17,7 +17,7 @@
 def install(options=None):
     """Install the reactor and parse any options we might need."""
     reactor_name = None
-    if options is not None and options.use_gui:
+    if options is not None and options['gui']:
         reactor_name = 'twisted.internet.gtk2reactor'
     else:
         reactor_name = 'twisted.internet.glib2reactor'
