@@ -22,12 +22,19 @@ REACTOR_URL = 'https://github.com/ghtdak/qtreactor'
 
 def install(options=None):
     """Install the reactor and parse any options we might need."""
-    if options is not None and options.use_gui:
+    if options is not None and options['gui']:
         from PyQt4.QtGui import QApplication
         # We must assign this to a variable, or we will get crashes in Qt
         # pylint: disable=W0612
         app = QApplication(sys.argv)
         # pylint: enable=W0612
 
-    qt4reactor = __import__('qtreactor.qt4reactor', None, None, [''])
+    try:
+        qt4reactor = __import__('qt4reactor', None, None, [''])
+    except ImportError:
+        # Leave this import in place for a couple of weeks
+        # until all the devs are using the packaged qt4reactor
+        # (nessita, 11-11-11)
+        qt4reactor = __import__('qtreactor.qt4reactor', None, None, [''])
+
     qt4reactor.install()
